@@ -13,7 +13,9 @@ class Cloud(object):
         self.f = f
 
     def __call__(self, *args):
-        return client.eval(self.f, args)
+        res = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1).eval(self.f, args)
+        print "res:", res
+        # return Husky.loads(res)
 
     def __getstate__(self):
         return Husky.dumps(self.f)
@@ -47,7 +49,7 @@ class CachedData(object):
         KVStore(config.host, self.name).set(self.id, value)
 
     def get(self, key):
-        return KVStore(self.name, config.host, config.port).get(key)
+        return KVStore(config.host, self.name).get(key)
 
     def __del__(self):
         pass
\ No newline at end of file
